<?php
/**
 * @package Blog_Time
 * @author Scott Reilly
 * @version 1.0.2
 */
/*
 * Blog Time plugin widget code
 *
 * Copyright (c) 2009-2010 by Scott Reilly (aka coffee2code)
 *
 */

if ( class_exists('WP_Widget') && !class_exists('BlogTimeWidget') ) :
class BlogTimeWidget extends WP_Widget {
	var $widget_id = 'blog_time';
	var $title = 'Blog Time';
	var $description = 'The time according to your blog.';
	var $config = array(
		// input can be 'checkbox', 'multiselect', 'select', 'short_text', 'text', 'textarea', 'hidden', or 'none'
		// datatype can be 'array' or 'hash'
		// can also specify input_attributes
		'title' => array('input' => 'text', 'default' => 'Blog Time',
				'label' => 'Title'),
		'format' => array('input' => 'text', 'default' => 'g:i A',
				'label' => 'Time format',
				'help' => 'PHP-style time format string. See <a href="http://php.net/date" title="">http://php.net/date</a> for more info.'),
		'before' => array('input' => 'text', 'default' => '',
				'label' => 'Before text',
				'help' => 'Text to display before the time.'),
		'after' => 	array('input' => 'text', 'default' => '',
				'label' => 'After text',
				'help' => 'Text to display after the time.')
	);
	var $defaults = array();

	/**
	 * Class constructor: initializes class variables and adds actions and filters.
	 */
	function BlogTimeWidget() {
		$this->title = __($this->title);
		foreach ( $this->config as $key => $value )
			$this->defaults[$key] = $value['default'];
		$widget_ops = array( 'classname' => 'widget_' . $this->widget_id, 'description' => __($this->description) );
		$control_ops = array(); //array( 'width' => 400, 'height' => 350, 'id_base' => $this->widget_id );
		$this->WP_Widget( $this->widget_id, $this->title, $widget_ops, $control_ops );
	}

	function widget( $args, $instance ) {
		extract($args);

		/* Settings */
		foreach ( array_keys($this->config) as $key )
			$$key = apply_filters('blog_time_'.$key, $instance[$key]);

		echo $before_widget;

		if ( $title )
			echo $before_title . $title . $after_title;

		// Widget content
		if ( $before ) echo $before;
		blog_time($format);
		if ( $after ) echo $after;

		echo $after_widget;
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		foreach ( $new_instance as $key => $value )
			$instance[$key] = $value;
		if ( !trim($instance['format']) )
			$instance['format'] = $this->defaults['format'];
		return $instance;
	}

	/**
	 * Outputs the form for the widget.
	 *
	 * @param string $instance The widget instance.
	 * @param array $exclude_options (optional) Array of options to exclude.
	 * @return null (Text is echoed; nothing is returned)
	 */
	function form( $instance, $exclude_options = array('') ) {
		$instance = wp_parse_args( (array) $instance, $this->defaults );
		$i = $j = 0;
		foreach ( $instance as $opt => $value ) {
			if ( $opt == 'submit' ) continue;
			if ( in_array($opt, $exclude_options) ) continue;
			$input = $this->config[$opt]['input'];
			$label = $this->config[$opt]['label'];
			if ( $input == 'none' ) {
				if ( $opt == 'more' ) {
					$i++; $j++;
					echo "<p>$label</p>";
					echo "<div class='widget-group widget-group-$i'>";
				} elseif ( $opt == 'endmore' ) {
					$j--;
					echo '</div>';
				}
				continue;
			}
			if ( $input == 'checkbox' ) {
				$checked = ($value == 1) ? 'checked=checked ' : '';
				$value = 1;
			} else {
				$checked = '';
			};
			if ( $input == 'multiselect' ) {
				// Do nothing since it needs the values as an array
			} elseif ( $this->config[$opt]['datatype'] == 'array' ) {
				if ( !is_array($value) )
					$value = '';
				else 
					$value = implode(('textarea' == $input ? "\n" : ', '), $value);
			} elseif ( $this->config[$opt]['datatype'] == 'hash' ) {
				if ( !is_array($value) )
					$value = '';
				else {
					$new_value = '';
					foreach ( $value AS $shortcut => $replacement )
						$new_value .= "$shortcut => $replacement\n";
					$value = $new_value;
				}
			}
			echo "<p>";
			$input_id = $this->get_field_id($opt);
			$input_name = $this->get_field_name($opt);
			$value = esc_attr($value);
			if ( $label && ($input != 'multiselect') ) echo "<label for='$input_id'>$label:</label> ";
			if ( $input == 'textarea' ) {
				echo "<textarea name='$input_name' id='$input_id' class='widefat' {$this->config[$opt]['input_attributes']}>" . $value . '</textarea>';
			} elseif ( $input == 'select' ) {
				echo "<select name='$input_name' id='$input_id'>";
				foreach ( $this->config[$opt]['options'] as $sopt ) {
					$selected = $value == $sopt ? " selected='selected'" : '';
					echo "<option value='$sopt'$selected>$sopt</option>";
				}
				echo "</select>";
			} elseif ( $input == 'multiselect' ) {
				echo '<fieldset style="border:1px solid #ccc; padding:2px 8px;">';
				if ( $label ) echo "<legend>$label: </legend>";
				foreach ( $this->config[$opt]['options'] as $sopt ) {
					$selected = in_array($sopt, $value) ? " checked='checked'" : '';
					echo "<input type='checkbox' name='$input_name' id='$input_id' value='$sopt'$selected>$sopt</input><br />";
				}
				echo '</fieldset>';
			} else {
				if ( $input == 'short_text' ) {
					$tclass = '';
					$tstyle = 'width:25px;';
					$input = 'text';
				} else {
					$tclass = 'widefat';
					$tstyle = '';
				}
				echo "<input name='$input_name' type='$input' id='$input_id' value='$value' class='$tclass' style='$tstyle' $checked {$this->config[$opt]['input_attributes']} />";
			}
			if ( $this->config[$opt]['help'] )
				echo "<br /><span style='color:#888; font-size:x-small;'>({$this->config[$opt]['help']})</span>";
			echo "</p>\n";
		}
		// Close any open divs
		for ( ; $j > 0; $j-- ) { echo '</div>'; }
	}

} // end class BlogTime

add_action( 'widgets_init', create_function('', 'register_widget(\'BlogTimeWidget\');') );

endif; // end if !class_exists()
?>